package edu.nyu.scps.progress;

import java.text.NumberFormat;

import android.app.Activity;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;

public class ProgressActivity extends Activity {
	static final int PROGRESS_DIALOG_ID = 0;
	ProgressDialog progressDialog;
	ProgressThread progressThread;
	final int max = 100;
	LinearLayout linearLayout;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		linearLayout = (LinearLayout)findViewById(R.id.linearLayout);
		final Button button = (Button)findViewById(R.id.button);

		button.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				showDialog(PROGRESS_DIALOG_ID);
			}
		});
	}

	//The handler belongs to the main thread, and receives messages from
	//the ProgressDialogThread.
	final Handler handler = new Handler() {
		@Override
		public void handleMessage(Message message) {
			final int progress = message.arg1;
			progressDialog.setProgress(progress);

			//Fade the background from black to white as time goes by.
			final int gray = Math.min(progress, max) * 255 / max;
			linearLayout.setBackgroundColor(Color.rgb(gray, gray, gray));

			if (progress >= max) {
				//Destroy the thread before dismissing the dialog.
				progressThread.setState(false);
				dismissDialog(PROGRESS_DIALOG_ID);
			}
		}
	};

	@Override
	protected Dialog onCreateDialog(int id, Bundle bundle) {
		switch (id) {
		case PROGRESS_DIALOG_ID:
			progressDialog = new ProgressDialog(this);
			progressDialog.setIconAttribute(android.R.attr.alertDialogIcon);
			progressDialog.setTitle(android.R.string.dialog_alert_title);
			progressDialog.setMessage("Are we making progress?");
			//Default is STYLE_SPINNER, which displays no numbers.
			progressDialog.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
			progressDialog.setMax(max);	//default is 100

			progressDialog.setProgressPercentFormat(NumberFormat.getPercentInstance());
			progressDialog.setProgressNumberFormat("%1d/%2d");

			//Android back button pressed?
			progressDialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
				@Override
				public void onCancel(DialogInterface dialog) {
					progressThread.setState(false);
				}
			});

			return progressDialog;

		default:
			return null;
		}
	}

	@Override
	protected void onPrepareDialog(int id, Dialog dialog) {
		switch(id) {
		case PROGRESS_DIALOG_ID:
			((ProgressDialog)dialog).setProgress(0);
			progressThread = new ProgressThread(handler);
			progressThread.start();
			break;

		default:
			break;
		}
	}
}